#
# spec file for package vocal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vocal
Version:        2.4.2
Release:        7.1
Summary:        A podcast client for the desktop
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Other
URL:            https://vocalproject.net/
Source:         https://github.com/needle-and-thread/vocal/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM vocal-fix-build.patch -- https://github.com/needle-and-thread/vocal/issues/483
Patch0:         vocal-fix-build.patch
# PATCH-FIX-UPSTREAM vocal-2.4.2-vala-0.56.patch -- https://github.com/VocalPodcastProject/vocal/pull/503, rebased on 2.4.2
Patch1:         vocal-2.4.2-vala-0.56.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  rsvg-convert
BuildRequires:  vala
BuildRequires:  pkgconfig(clutter-gst-3.0)
BuildRequires:  pkgconfig(clutter-gtk-1.0)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
%glib2_gsettings_schema_requires

%description
A podcast application designed for Elementary OS and other GTK-based
Linux desktops. Includes a built-in video player, automatic updating,
smart library management, library importing and exporting, custom
skip intervals, and more.

%lang_package

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install
%find_lang %{name} %{?no_lang_C}

# CONVERT SVG ICONS INSTALLED INTO NON-SCALABLE DIR TO PNG ONES
for i in 16 22 24 32 48 64 128
do
  rsvg-convert  -o %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/com.github.needleandthread.vocal.png \
    %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/com.github.needleandthread.vocal.svg
  rm %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/com.github.needleandthread.vocal.svg
done

%fdupes %{buildroot}%{_datadir}/locale/

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/com.github.needleandthread.vocal
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/applications/com.github.needleandthread.vocal.desktop
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/%{name}/

%files lang -f %{name}.lang

%changelog
* Mon Dec 16 2024 Atri Bhattacharya <badshah400@gmail.com>
- Some miscellaneous cleanups for specfile:
  * Drop use of deprecated suse_update_desktop_file macro.
  * Do not recommend lang package, this is more accurately handled
    by the lan-package macros already.
  * Drop conditionals supporting EOL distro versions.
  * Use cmake macros for build and install.
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Sat Jun 25 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add vocal-2.4.2-vala-0.56.patch: Fix build with Vala 0.56.
* Thu Oct  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add vocal-fix-build.patch: Fix build with granite 6.0 and newer.
  Patch from arch linux.
  https://github.com/needle-and-thread/vocal/issues/483
- Update URL to new home.
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Tue Jun 25 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.2:
  + This point release changes all the application IDs to
    com.needleandthread.vocal to fix some issues with dbus and
    flatpaks
- Adapt to exec, .desktop file, and icon name changes.
- Drop post* scriptlets as they catered to ancient openSUSE
  releases <= 13.2.
* Thu May 16 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.1:
  + Fix issue with the progress-bar where only its left half could
    be used for seeking.
- Run spec-cleaner for minor cleanups including using %%%%license to
  package the COPYING flie.
* Tue Apr 23 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.0:
  + Switch between 'light' and 'dark' modes using the option in
    the gear menu
  + Built-in Internet Archive episode uploads (for Creative
    Commons licensed feeds)
  + Better search results
  + Scrolling while hovering over the seekbar now seeks through
    the current episode
  + Support for Atom podcast feeds
  + Dramatically improved episode browsing (can now list both
    reverse-chronological or chronological - your choice)
  + New and updated translations throughout many languages
  + Lots of stability and performance enhancements under the hood
* Thu Nov 15 2018 badshah400@gmail.com
- Update to version 2.3.0:
  + Added new in-app volume controls.
  + Dramatic improvements to the new episode count badges.
  + Improved the search view to make it clear when Vocal is
    loading results from iTunes.
  + Podcasts licensed as Creative Commons now display a Creative
    Commons logo.
  + Improved look and feel throughout the app.
  + New episodes are now sorted by release date rather than just
    their position in the RSS feed (most users will not notice a
    difference as this was an edge-case).
  + Fixed navigation issues that could cause new users to get
    stuck during the setup process.
  + Fixed several issues with the new episodes view button either
    being visible when it should not be, or not being visible when
    it should.
  + Database handling and performance improvements.
  + General stability improvements.
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 2.2.0:
  * Fixed the infamous "freeze on launch" bug which prevented some
    users from accessing their library.
  * Added a New Episode view to see all the unplayed episodes in
    your library at once.
  * Fixed an annoyance where Vocal would sometimes re-download an
    episode that had already been downloaded.
  * Performance and stability improvements with checking for new
    episodes.
  * Improved performance of the iTunes podcast directory
    (specifically related to the loading of hi res images).
  * Improved logging and debugging support.
  * Many other small performance and stability enhancements.
* Mon Feb  5 2018 badshah400@gmail.com
- Update to version 2.1.6:
  * This update fixes an issue where the .desktop file was using
    the RDNN instead of the actual app name.
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 2.1.5:
  + Bug fixes (undocumented).
* Sun Dec 31 2017 badshah400@gmail.com
- Update to version 2.1.0:
  * Added HiDPI support for all images so everything looks nice
    and sharp no matter how fancy your display is.
  * Fixed an issue where Vocal would not show you the time elapsed
    or remaining in an episode immediately after relaunching the
    app.
  * Reduced the animation time for switching between different
    views so that it feels extra snappy.
  * Gave the search results view a shave and a haircut. Two bits.
  * Fixed a few issues where Vocal would be grouchy about showing
    certain episode descriptions.
  * When importing several podcasts the progress bar now stays one
    size so you can actually judge the progress correctly.
  * You can now drag and drop items in the play queue to rearrange
    their order.
  * Lots more checking to make sure that things exist so it won't
  * crash nearly as much (hopefully never).
- Appdata moved to %%{_datadir}/metainfo/; adapt file list
  accordingly.
- Only run post scripts for openSUSE <= 1320; for newer versions
  rpm triggers take care of running these scripts automatically.
* Sun Jun 25 2017 badshah400@gmail.com
- Update to version 2.0.20:
  * Fixed a major bug that was leading to crashing when clicking
    on certain podcasts in the library view
  * Use the built-in card CSS class for items in the podcast
    directory when running on elementary OS to make things look
    even sexier
  * Added drag-and-drop support to the queue and prevent adding
    duplicate episodes
- Drop vocal-fix-application-icons.patch: incorporated upstream.
* Sat Apr 15 2017 badshah400@gmail.com
- Update vocal-fix-application-icons.patch to fix one additional
  button icon; patch submitted upstream
  (gh#needle-and-thread/vocal#146).
* Thu Apr 13 2017 badshah400@gmail.com
- Update to version 2.0.12-beta.
- Drop vocal-cmake-fix-install-filenames.patch: incorporated
  upstream.
* Mon Feb 13 2017 badshah400@gmail.com
- Update to version 2.0.10-beta.
- Add patch vocal-cmake-fix-install-filenames.patch to fix
  lingering issues relating to the vocalapp -> needle-and-thread
  github project rename.
* Tue Nov 29 2016 badshah400@gmail.com
- Update to version 2.0.8-beta.
- Drop upstreamed patches:
  * vocal-dont-hardcode-paths.patch
  * vocal-crash-on-percent-sign.patch
- Rebase vocal-fix-application-icons.patch.
* Sun Nov 20 2016 badshah400@gmail.com
- Add vocal-crash-on-percent-sign.patch: Fix crashing when
  podcast name contains a "%%" sign.
* Sun Oct 30 2016 badshah400@gmail.com
- Add vocal-fix-application-icons.patch: Fix icons in application
  toolbars not showing up; patch taken from upstream git
  (gh#vocalapp/vocal#31, gh#vocalapp/vocal#82).
* Sun Oct 30 2016 badshah400@gmail.com
- Update to version 2.0.7-beta:
  + Update CMakeLists.txt.
- Drop vocal-fix-webkitgtk-dep.patch, upstreamed.
- Add, rather than replace, new Categories to .desktop file using
  %%suse_update_desktop_file.
* Thu Apr 28 2016 badshah400@gmail.com
- Update to version 2.0.6-beta (use custom version 1.99.x until
  full 2.0 version comes out).
- Add vocal-fix-webkitgtk-dep.patch to fix obvious library
  naming mistake in cmake file
- Add vocal-locale-dir.patch to move all translations from the
  upstream installed custom dir to openSUSE's standard locale dir;
  not only does it make the location of locale files standard, but
  this also allows us to use standard tools like %%find_lang during
  the build process.
- Update build dependencies for new version:
  + pkgconfig(webkit2gtk-4.0)
  + pkgconfig(libsoub-2.4)
  + pkgconfig(gee-0.8)
  + pkgconfig(gthread-2.0)
- Clean up spec file (prepare for sr into Factory):
  + Use full URL for source tarball.
  + Change version number to be consistent with upstream tarball
    naming.
* Sat Mar  5 2016 and.november@opensuse.org
- initial package (version 1.0) for openSUSE
